@@ -1,4 +1,4 @@
-
+from __future__ import absolute_import
 
 
 import sys
@@ -6,6 +6,4 @@ import sys
 if sys.version_info[0] == 3:
     from multiprocessing.connection import *  # noqa
 else:
-    from ._connection import *
-
-
+    from ._connection import *                # noqa
